@@ -34,8 +34,6 @@
 #include "gvc-applet.h"
 #include "gvc-stream-applet-icon.h"
 
-#define GVC_APPLET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GVC_TYPE_APPLET, GvcAppletPrivate))
-
 static const gchar *icon_names_output[] = {
         "audio-volume-muted",
         "audio-volume-low",
@@ -76,10 +74,7 @@ struct _GvcAppletPrivate
         GtkActionGroup      *action_group;
 };
 
-static void gvc_applet_class_init (GvcAppletClass *klass);
-static void gvc_applet_init       (GvcApplet      *applet);
-
-G_DEFINE_TYPE (GvcApplet, gvc_applet, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (GvcApplet, gvc_applet, G_TYPE_OBJECT)
 
 static void
 update_icon_input (GvcApplet *applet)
@@ -116,7 +111,7 @@ update_icon_input (GvcApplet *applet)
                                         g_debug ("Found a recording application control %s",
                                                  mate_mixer_stream_control_get_label (input));
 
-                                        if G_UNLIKELY (control == NULL) {
+                                        if (G_UNLIKELY (control == NULL)) {
                                                 /* In the unlikely case when there is no
                                                  * default input control, use the application
                                                  * control for the icon */
@@ -131,7 +126,7 @@ update_icon_input (GvcApplet *applet)
                                     strcmp (app_id, "org.PulseAudio.pavucontrol") != 0) {
                                         g_debug ("Found a recording application %s", app_id);
 
-                                        if G_UNLIKELY (control == NULL)
+                                        if (G_UNLIKELY (control == NULL))
                                                 control = input;
 
                                         show = TRUE;
@@ -204,7 +199,7 @@ on_input_stream_control_added (MateMixerStream *stream,
         MateMixerStreamControl *control;
 
         control = mate_mixer_stream_get_control (stream, name);
-        if G_LIKELY (control != NULL) {
+        if (G_LIKELY (control != NULL)) {
                 MateMixerStreamControlRole role = mate_mixer_stream_control_get_role (control);
 
                 /* Non-application input control doesn't affect the icon */
@@ -352,10 +347,10 @@ gvc_applet_start (GvcApplet *applet)
 {
         g_return_if_fail (GVC_IS_APPLET (applet));
 
-        if G_UNLIKELY (applet->priv->running == TRUE)
+        if (G_UNLIKELY (applet->priv->running == TRUE))
                 return;
 
-        if G_UNLIKELY (mate_mixer_context_open (applet->priv->context) == FALSE) {
+        if (G_UNLIKELY (mate_mixer_context_open (applet->priv->context) == FALSE)) {
                 /* Normally this should never happen, in the worst case we
                  * should end up with the Null module */
                 g_warning ("Failed to connect to a sound system");
@@ -393,14 +388,12 @@ gvc_applet_class_init (GvcAppletClass *klass)
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
         object_class->dispose = gvc_applet_dispose;
-
-        g_type_class_add_private (klass, sizeof (GvcAppletPrivate));
 }
 
 static void
 gvc_applet_init (GvcApplet *applet)
 {
-        applet->priv = GVC_APPLET_GET_PRIVATE (applet);
+        applet->priv = gvc_applet_get_instance_private (applet);
 
         applet->priv->icon_input  = gvc_stream_applet_icon_new (NULL, icon_names_input);
         applet->priv->icon_output = gvc_stream_applet_icon_new (NULL, icon_names_output);
