@@ -31,8 +31,6 @@
 #include "gvc-level-bar.h"
 #include "gvc-utils.h"
 
-#define GVC_LEVEL_BAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GVC_TYPE_LEVEL_BAR, GvcLevelBarPrivate))
-
 #define NUM_BOXES                  15
 #define MIN_HORIZONTAL_BAR_WIDTH   150
 #define HORIZONTAL_BAR_HEIGHT      6
@@ -77,11 +75,9 @@ enum
 
 static GParamSpec *properties[N_PROPERTIES] = { NULL, };
 
-static void gvc_level_bar_class_init (GvcLevelBarClass *klass);
-static void gvc_level_bar_init       (GvcLevelBar      *bar);
 static void gvc_level_bar_finalize   (GObject          *object);
 
-G_DEFINE_TYPE (GvcLevelBar, gvc_level_bar, GTK_TYPE_WIDGET)
+G_DEFINE_TYPE_WITH_PRIVATE (GvcLevelBar, gvc_level_bar, GTK_TYPE_WIDGET)
 
 static gboolean
 layout_changed (LevelBarLayout *layout1, LevelBarLayout *layout2)
@@ -569,9 +565,10 @@ gvc_level_bar_draw (GtkWidget *widget, cairo_t *cr)
 
         if (bar->priv->orientation == GTK_ORIENTATION_VERTICAL) {
                 int i;
-                int by;
 
                 for (i = 0; i < NUM_BOXES; i++) {
+                        int by;
+
                         by = i * bar->priv->layout.delta;
                         curved_rectangle (cr,
                                           bar->priv->layout.area.x + 0.5,
@@ -608,7 +605,6 @@ gvc_level_bar_draw (GtkWidget *widget, cairo_t *cr)
                 }
         } else {
                 int i;
-                int bx;
 
                 if (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL) {
                         GtkAllocation allocation;
@@ -620,6 +616,8 @@ gvc_level_bar_draw (GtkWidget *widget, cairo_t *cr)
                 }
 
                 for (i = 0; i < NUM_BOXES; i++) {
+                        int bx;
+
                         bx = i * bar->priv->layout.delta;
                         curved_rectangle (cr,
                                           bx + 0.5,
@@ -716,8 +714,6 @@ gvc_level_bar_class_init (GvcLevelBarClass *klass)
                                   G_PARAM_STATIC_STRINGS);
 
         g_object_class_install_properties (object_class, N_PROPERTIES, properties);
-
-        g_type_class_add_private (klass, sizeof (GvcLevelBarPrivate));
 }
 
 static void
@@ -727,7 +723,7 @@ gvc_level_bar_init (GvcLevelBar *bar)
 
         gtk_style_context_add_class (context, GTK_STYLE_CLASS_LIST_ROW);
 
-        bar->priv = GVC_LEVEL_BAR_GET_PRIVATE (bar);
+        bar->priv = gvc_level_bar_get_instance_private (bar);
 
         bar->priv->peak_adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0.0,
                                                                          0.0,
