@@ -38,8 +38,6 @@
 #include "gvc-speaker-test.h"
 #include "gvc-utils.h"
 
-#define GVC_MIXER_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GVC_TYPE_MIXER_DIALOG, GvcMixerDialogPrivate))
-
 struct _GvcMixerDialogPrivate
 {
         MateMixerContext *context;
@@ -110,8 +108,6 @@ static const guint tab_accel_keys[] = {
         GDK_KEY_1, GDK_KEY_2, GDK_KEY_3, GDK_KEY_4, GDK_KEY_5
 };
 
-static void gvc_mixer_dialog_class_init (GvcMixerDialogClass    *klass);
-static void gvc_mixer_dialog_init       (GvcMixerDialog         *dialog);
 static void gvc_mixer_dialog_finalize   (GObject                *object);
 
 static void add_stream                  (GvcMixerDialog         *dialog,
@@ -135,7 +131,7 @@ static gboolean dialog_page_scroll_event_cb (GtkWidget          *widget,
                                              GdkEventScroll     *event,
                                              GtkWindow          *window);
 
-G_DEFINE_TYPE (GvcMixerDialog, gvc_mixer_dialog, GTK_TYPE_DIALOG)
+G_DEFINE_TYPE_WITH_PRIVATE (GvcMixerDialog, gvc_mixer_dialog, GTK_TYPE_DIALOG)
 
 static MateMixerSwitch *
 find_stream_port_switch (MateMixerStream *stream)
@@ -380,13 +376,14 @@ static void
 set_output_stream (GvcMixerDialog *dialog, MateMixerStream *stream)
 {
         GtkTreeModel           *model;
-        MateMixerSwitch        *swtch;
         MateMixerStreamControl *control;
 
         control = gvc_channel_bar_get_control (GVC_CHANNEL_BAR (dialog->priv->output_bar));
         if (control != NULL) {
                 /* Disconnect port switch of the previous stream */
                 if (dialog->priv->output_port_combo != NULL) {
+                        MateMixerSwitch        *swtch;
+
                         swtch = g_object_get_data (G_OBJECT (dialog->priv->output_port_combo),
                                                    "switch");
                         if (swtch != NULL)
@@ -405,7 +402,6 @@ set_output_stream (GvcMixerDialog *dialog, MateMixerStream *stream)
                 /* Move all stored controls to the newly selected default stream */
                 while (controls != NULL) {
                         MateMixerStream        *parent;
-                        MateMixerStreamControl *control;
 
                         control = MATE_MIXER_STREAM_CONTROL (controls->data);
                         parent  = mate_mixer_stream_control_get_stream (control);
@@ -535,13 +531,14 @@ static void
 set_input_stream (GvcMixerDialog *dialog, MateMixerStream *stream)
 {
         GtkTreeModel           *model;
-        MateMixerSwitch        *swtch;
         MateMixerStreamControl *control;
 
         control = gvc_channel_bar_get_control (GVC_CHANNEL_BAR (dialog->priv->input_bar));
         if (control != NULL) {
                 /* Disconnect port switch of the previous stream */
                 if (dialog->priv->input_port_combo != NULL) {
+                        MateMixerSwitch        *swtch;
+
                         swtch = g_object_get_data (G_OBJECT (dialog->priv->input_port_combo),
                                                    "switch");
                         if (swtch != NULL)
@@ -585,8 +582,7 @@ set_input_stream (GvcMixerDialog *dialog, MateMixerStream *stream)
                 }
 
                 if (page == PAGE_INPUT) {
-                        MateMixerStreamControl *control =
-                                gvc_channel_bar_get_control (GVC_CHANNEL_BAR (dialog->priv->input_bar));
+                        control = gvc_channel_bar_get_control (GVC_CHANNEL_BAR (dialog->priv->input_bar));
 
                         if (G_LIKELY (control != NULL))
                                 mate_mixer_stream_control_set_monitor_enabled (control, TRUE);
@@ -794,7 +790,7 @@ on_stream_control_added (MateMixerStream *stream,
         MateMixerStreamControlRole role;
 
         control = mate_mixer_stream_get_control (stream, name);
-        if G_UNLIKELY (control == NULL)
+        if (G_UNLIKELY (control == NULL))
                 return;
 
         role = mate_mixer_stream_control_get_role (control);
@@ -1892,10 +1888,10 @@ gvc_mixer_dialog_constructor (GType                  type,
         GtkWidget        *ebox;
         GtkTreeSelection *selection;
         GtkAccelGroup    *accel_group;
-        GClosure         *closure;
         GtkTreeIter       iter;
         gint              i;
         const GList      *list;
+        GClosure         *closure = NULL;
 
         object = G_OBJECT_CLASS (gvc_mixer_dialog_parent_class)->constructor (type,
                                                                               n_construct_properties,
@@ -2318,14 +2314,12 @@ gvc_mixer_dialog_class_init (GvcMixerDialogClass *klass)
 
         GtkWidgetClass *widget_class  = GTK_WIDGET_CLASS (klass);
         gtk_widget_class_set_css_name (widget_class, "GvcMixerDialog");
-
-        g_type_class_add_private (klass, sizeof (GvcMixerDialogPrivate));
 }
 
 static void
 gvc_mixer_dialog_init (GvcMixerDialog *dialog)
 {
-        dialog->priv = GVC_MIXER_DIALOG_GET_PRIVATE (dialog);
+        dialog->priv = gvc_mixer_dialog_get_instance_private (dialog);
 
         dialog->priv->bars = g_hash_table_new (g_str_hash, g_str_equal);
         dialog->priv->size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
